==> qtjambi-network-debuginfo-macos-6.5.7.jar: sources/QtJambiNetwork/QLocalServer_shell.h <==
#ifndef QLOCALSERVER_SHELL_H
#define QLOCALSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtnetwork-config.h>
#if QT_CONFIG(localserver)
#include <QtNetwork/qlocalserver.h>
#endif //QT_CONFIG(localserver)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qabstractsocket.h>
#if QT_CONFIG(localserver)
#include <QtNetwork/qlocalsocket.h>
#endif //QT_CONFIG(localserver)
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(localserver)

class QLocalServer_shell : public QLocalServer, public QtJambiShellInterface
{
public:
    QLocalServer_shell(QObject* parent0 = nullptr);
    ~QLocalServer_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QLocalServer_mshell;
    friend class QLocalServer_oshell;
};


class QLocalServer_mshell : public QLocalServer_shell
{
public:
    using QLocalServer_shell::QLocalServer_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QLocalServer_oshell : public QLocalServer_mshell
{
public:
    using QLocalServer_mshell::QLocalServer_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasPendingConnections() const override;
    void incomingConnection(quintptr socketDescriptor0) override;
    QLocalSocket* nextPendingConnection() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLocalServer_access : public QLocalServer
{
    jboolean __qt_hasPendingConnections_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_incomingConnection_quintptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong socketDescriptor0);
    jobject __qt_nextPendingConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QT_CONFIG(localserver)
#endif // QLOCALSERVER_SHELL_H

==> qtjambi-network-debuginfo-macos-6.6.1.jar: sources/QtJambiNetwork/QLocalServer_shell.h <==
#ifndef QLOCALSERVER_SHELL_H
#define QLOCALSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtnetwork-config.h>
#if QT_CONFIG(localserver)
#include <QtNetwork/qlocalserver.h>
#endif //QT_CONFIG(localserver)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtNetwork/qabstractsocket.h>
#if QT_CONFIG(localserver)
#include <QtNetwork/qlocalsocket.h>
#endif //QT_CONFIG(localserver)
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(localserver)

class QLocalServer_shell : public QLocalServer, public QtJambiShellInterface
{
public:
    QLocalServer_shell(QObject* parent0 = nullptr);
    ~QLocalServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasPendingConnections() const override;
    void incomingConnection(quintptr socketDescriptor0) override;
    QLocalSocket* nextPendingConnection() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLocalServer_access : public QLocalServer
{
    jboolean __qt_hasPendingConnections(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_incomingConnection_quintptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong socketDescriptor0);
    jobject __qt_nextPendingConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QT_CONFIG(localserver)
#endif // QLOCALSERVER_SHELL_H
